JsonExpression

Enum JsonExpression 

pub enum JsonExpression {
Show 38 variants None, Bool { value: String, }, Number { value: String, }, Text { value: String, }, Temporal { value: String, }, Column { namespace: String, shape: String, name: String, }, AccessSource { namespace: String, shape: String, name: String, }, Variable { name: String, }, ParameterPositional { position: String, }, ParameterNamed { name: String, }, GreaterThan { left: Box<JsonExpression>, right: Box<JsonExpression>, }, GreaterThanEqual { left: Box<JsonExpression>, right: Box<JsonExpression>, }, LessThan { left: Box<JsonExpression>, right: Box<JsonExpression>, }, LessThanEqual { left: Box<JsonExpression>, right: Box<JsonExpression>, }, Equal { left: Box<JsonExpression>, right: Box<JsonExpression>, }, NotEqual { left: Box<JsonExpression>, right: Box<JsonExpression>, }, And { left: Box<JsonExpression>, right: Box<JsonExpression>, }, Or { left: Box<JsonExpression>, right: Box<JsonExpression>, }, Xor { left: Box<JsonExpression>, right: Box<JsonExpression>, }, Add { left: Box<JsonExpression>, right: Box<JsonExpression>, }, Sub { left: Box<JsonExpression>, right: Box<JsonExpression>, }, Mul { left: Box<JsonExpression>, right: Box<JsonExpression>, }, Div { left: Box<JsonExpression>, right: Box<JsonExpression>, }, Rem { left: Box<JsonExpression>, right: Box<JsonExpression>, }, Alias { alias: String, expression: Box<JsonExpression>, }, Cast { expression: Box<JsonExpression>, to: String, }, Call { function: String, args: Vec<JsonExpression>, }, Tuple { expressions: Vec<JsonExpression>, }, List { expressions: Vec<JsonExpression>, }, Prefix { operator: String, expression: Box<JsonExpression>, }, Between { value: Box<JsonExpression>, lower: Box<JsonExpression>, upper: Box<JsonExpression>, }, In { value: Box<JsonExpression>, list: Box<JsonExpression>, negated: bool, }, Contains { value: Box<JsonExpression>, list: Box<JsonExpression>, }, If { condition: Box<JsonExpression>, then: Box<JsonExpression>, else_ifs: Vec<JsonElseIf>, else_expr: Option<Box<JsonExpression>>, }, Map { expressions: Vec<JsonExpression>, }, Extend { expressions: Vec<JsonExpression>, }, Type { ty: String, }, FieldAccess { object: Box<JsonExpression>, field: String, },
}
JSON-serializable expression for query builders.

This enum mirrors the Expression type but uses simple owned types instead of lifetimed Fragments, making it suitable for JSON serialization.

Variants



None



Bool

Fields

value: String


Number

Fields

value: String


Text

Fields

value: String


Temporal

Fields

value: String


Column

Fields

namespace: String
shape: String
name: String


AccessSource

Fields

namespace: String
shape: String
name: String


Variable

Fields

name: String


ParameterPositional

Fields

position: String


ParameterNamed

Fields

name: String


GreaterThan



GreaterThanEqual



LessThan



LessThanEqual



Equal



NotEqual



And



Or



Xor



Add



Sub



Mul



Div



Rem



Alias

Fields

alias: String
expression: Box<JsonExpression>


Cast

Fields

expression: Box<JsonExpression>


Call

Fields

function: String


Tuple

Fields

expressions: Vec<JsonExpression>


List

Fields

expressions: Vec<JsonExpression>


Prefix

Fields

operator: String
expression: Box<JsonExpression>


Between



In

Fields

negated: bool


Contains



If

Fields

condition: Box<JsonExpression>
else_ifs: Vec<JsonElseIf>


Map

Fields

expressions: Vec<JsonExpression>


Extend

Fields

expressions: Vec<JsonExpression>


Type

Fields



FieldAccess

Fields

field: String