FlowNodeType

Enum FlowNodeType 

pub enum FlowNodeType {
Show 22 variants SourceInlineData {}, SourceTable { table: TableId, }, SourceView { view: ViewId, }, SourceFlow { flow: FlowId, }, SourceRingBuffer { ringbuffer: RingBufferId, }, SourceSeries { series: SeriesId, }, Filter { conditions: Vec<Expression>, }, Gate { conditions: Vec<Expression>, }, Map { expressions: Vec<Expression>, }, Extend { expressions: Vec<Expression>, }, Join { join_type: JoinType, left: Vec<Expression>, right: Vec<Expression>, alias: Option<String>, }, Aggregate { by: Vec<Expression>, map: Vec<Expression>, }, Append, Sort { by: Vec<SortKey>, }, Take { limit: usize, }, Distinct { expressions: Vec<Expression>, }, Apply { operator: String, expressions: Vec<Expression>, }, SinkTableView { view: ViewId, table: TableId, }, SinkRingBufferView { view: ViewId, ringbuffer: RingBufferId, capacity: u64, propagate_evictions: bool, }, SinkSeriesView { view: ViewId, series: SeriesId, key: SeriesKey, }, SinkSubscription { subscription: SubscriptionId, }, Window { kind: WindowKind, group_by: Vec<Expression>, aggregations: Vec<Expression>, ts: Option<String>, },
}

Variants



SourceInlineData



SourceTable

Fields

table: TableId


SourceView

Fields

view: ViewId


SourceFlow

Fields

flow: FlowId


SourceRingBuffer

Fields

ringbuffer: RingBufferId


SourceSeries

Fields

series: SeriesId


Filter

Fields

conditions: Vec<Expression>


Gate

Fields

conditions: Vec<Expression>


Map

Fields

expressions: Vec<Expression>


Extend

Fields

expressions: Vec<Expression>


Join

Fields

join_type: JoinType


Aggregate



Append



Sort

Fields



Take

Fields

limit: usize


Distinct

Fields

expressions: Vec<Expression>


Apply

Fields

operator: String
expressions: Vec<Expression>


SinkTableView

Fields

view: ViewId
table: TableId


SinkRingBufferView

Fields

view: ViewId
ringbuffer: RingBufferId
capacity: u64
propagate_evictions: bool


SinkSeriesView

Fields

view: ViewId
series: SeriesId


SinkSubscription

Fields

subscription: SubscriptionId


Window

Fields

group_by: Vec<Expression>
aggregations: Vec<Expression>

Implementations

Source

impl FlowNodeType

pub fn discriminator(&self) -> u8

Returns a discriminator value for this node type variant. Must match indices in FLOW_NODE_TYPE_NAMES in catalog/vtable/system/flow_node_types.rs

pub fn primitive_source_shape_id(&self) -> Option<ShapeId>

If this node is a primitive data source (table, ring buffer, or series), returns its ShapeId. Returns None for all other node types.

Uses an exhaustive match so that adding a new variant to FlowNodeType produces a compiler error, forcing the author to decide whether the new variant is a primitive source.