pub enum FlowNodeType {
Show 22 variants
SourceInlineData {},
SourceTable {
table: TableId,
},
SourceView {
view: ViewId,
},
SourceFlow {
flow: FlowId,
},
SourceRingBuffer {
ringbuffer: RingBufferId,
},
SourceSeries {
series: SeriesId,
},
Filter {
conditions: Vec<Expression>,
},
Gate {
conditions: Vec<Expression>,
},
Map {
expressions: Vec<Expression>,
},
Extend {
expressions: Vec<Expression>,
},
Join {
join_type: JoinType,
left: Vec<Expression>,
right: Vec<Expression>,
alias: Option<String>,
},
Aggregate {
by: Vec<Expression>,
map: Vec<Expression>,
},
Append,
Sort {
by: Vec<SortKey>,
},
Take {
limit: usize,
},
Distinct {
expressions: Vec<Expression>,
},
Apply {
operator: String,
expressions: Vec<Expression>,
},
SinkTableView {
view: ViewId,
table: TableId,
},
SinkRingBufferView {
view: ViewId,
ringbuffer: RingBufferId,
capacity: u64,
propagate_evictions: bool,
},
SinkSeriesView {
view: ViewId,
series: SeriesId,
key: SeriesKey,
},
SinkSubscription {
subscription: SubscriptionId,
},
Window {
kind: WindowKind,
group_by: Vec<Expression>,
aggregations: Vec<Expression>,
ts: Option<String>,
},
}Variants
SourceInlineData
SourceTable
SourceView
SourceFlow
SourceRingBuffer
Fields

ringbuffer: RingBufferIdSourceSeries
Filter
Fields

conditions: Vec<Expression>Gate
Fields

conditions: Vec<Expression>Map
Fields

expressions: Vec<Expression>Extend
Fields

expressions: Vec<Expression>Join
Aggregate
Append
Sort
Take
Distinct
Fields

expressions: Vec<Expression>Apply
SinkTableView
SinkRingBufferView
SinkSeriesView
SinkSubscription
Fields

subscription: SubscriptionIdWindow
Implementations
Sourceimpl FlowNodeType
impl FlowNodeType
Sourcepub fn discriminator(&self) -> u8
pub fn discriminator(&self) -> u8
Returns a discriminator value for this node type variant. Must match indices in FLOW_NODE_TYPE_NAMES in catalog/vtable/system/flow_node_types.rs
Sourcepub fn primitive_source_shape_id(&self) -> Option<ShapeId>
pub fn primitive_source_shape_id(&self) -> Option<ShapeId>
If this node is a primitive data source (table, ring buffer, or series),
returns its ShapeId. Returns None for all other node types.
Uses an exhaustive match so that adding a new variant to FlowNodeType
produces a compiler error, forcing the author to decide whether the new
variant is a primitive source.